View Source Runbox.Runtime.Stage.Timezip (runbox v25.0.0)
Timezip component responsible for merging multiple message streams using time for Stage runtime.
Timezip component responsible for merging multiple message streams using time for Stage runtime.